==> blender_2.79.b+dfsg0.orig.tar.xz: blender-2.79b+dfsg0.orig/release/scripts/addons/presets/operator/mesh.landscape_add/slick_rock.py <==
import bpy
op = bpy.context.active_operator

op.ant_terrain_name = 'Landscape'
op.land_material = ''
op.water_material = ''
op.texture_block = ''
op.at_cursor = True
op.smooth_mesh = True
op.tri_face = False
op.sphere_mesh = False
op.subdivision_x = 160
op.subdivision_y = 160
op.mesh_size = 2.0
op.mesh_size_x = 2.0
op.mesh_size_y = 2.0
op.random_seed = 87
op.noise_offset_x = 0.0
op.noise_offset_y = 0.0
op.noise_offset_z = 0.0
op.noise_size_x = 1.0
op.noise_size_y = 1.0
op.noise_size_z = 1.0
op.noise_size = 1.0
op.noise_type = 'slick_rock'
op.basis_type = '0'
op.vl_basis_type = '7'
op.distortion = 1.0
op.hard_noise = '0'
op.noise_depth = 8
op.amplitude = 0.5
op.frequency = 2.0
op.dimension = 1.0
op.lacunarity = 2.0
op.offset = 1.100000023841858
op.gain = 2.5
op.marble_bias = '0'
op.marble_sharp = '0'
op.marble_shape = '0'
op.height = 0.5
op.height_invert = False
op.height_offset = 0.10000000149011612
op.fx_mixfactor = 0.0
op.fx_mix_mode = '0'
op.fx_type = '0'
op.fx_bias = '0'
op.fx_turb = 0.0
op.fx_depth = 0
op.fx_amplitude = 0.5
op.fx_frequency = 1.5
op.fx_size = 1.0
op.fx_loc_x = 0.0
op.fx_loc_y = 0.0
op.fx_height = 0.5
op.fx_invert = False
op.fx_offset = 0.0
op.edge_falloff = '3'
op.falloff_x = 3.0
op.falloff_y = 3.0
op.edge_level = 0.0
op.maximum = 1.0
op.minimum = -1.0
op.vert_group = ''
op.strata = 5.0
op.strata_type = '0'
op.water_plane = False
op.water_level = 0.009999999776482582
op.remove_double = False
op.show_main_settings = True
op.show_noise_settings = True
op.show_displace_settings = True
op.refresh = True
op.auto_refresh = True

==> blender_2.82.a+dfsg.orig.tar.xz: blender-2.82a/release/scripts/addons/presets/operator/mesh.landscape_add/slick_rock.py <==
import bpy
op = bpy.context.active_operator

op.ant_terrain_name = 'Landscape'
op.land_material = ''
op.water_material = ''
op.texture_block = ''
op.at_cursor = True
op.smooth_mesh = True
op.tri_face = False
op.sphere_mesh = False
op.subdivision_x = 160
op.subdivision_y = 160
op.mesh_size = 2.0
op.mesh_size_x = 2.0
op.mesh_size_y = 2.0
op.random_seed = 87
op.noise_offset_x = 0.0
op.noise_offset_y = 0.0
op.noise_offset_z = 0.0
op.noise_size_x = 1.0
op.noise_size_y = 1.0
op.noise_size_z = 1.0
op.noise_size = 1.0
op.noise_type = 'slick_rock'
op.basis_type = 'BLENDER'
op.vl_basis_type = 'VORONOI_F2F1'
op.distortion = 1.0
op.hard_noise = '0'
op.noise_depth = 8
op.amplitude = 0.5
op.frequency = 2.0
op.dimension = 1.0
op.lacunarity = 2.0
op.offset = 1.100000023841858
op.gain = 2.5
op.marble_bias = '0'
op.marble_sharp = '0'
op.marble_shape = '0'
op.height = 0.5
op.height_invert = False
op.height_offset = 0.10000000149011612
op.fx_mixfactor = 0.0
op.fx_mix_mode = '0'
op.fx_type = '0'
op.fx_bias = '0'
op.fx_turb = 0.0
op.fx_depth = 0
op.fx_amplitude = 0.5
op.fx_frequency = 1.5
op.fx_size = 1.0
op.fx_loc_x = 0.0
op.fx_loc_y = 0.0
op.fx_height = 0.5
op.fx_invert = False
op.fx_offset = 0.0
op.edge_falloff = '3'
op.falloff_x = 3.0
op.falloff_y = 3.0
op.edge_level = 0.0
op.maximum = 1.0
op.minimum = -1.0
op.vert_group = ''
op.strata = 5.0
op.strata_type = '0'
op.water_plane = False
op.water_level = 0.009999999776482582
op.remove_double = False
op.show_main_settings = True
op.show_noise_settings = True
op.show_displace_settings = True
op.refresh = True
op.auto_refresh = True
